@@ -3,6 +3,7 @@ package AI::Genetic::Pro::Crossover::PointsSimple;
 use warnings;
 use strict;
 use Clone qw( clone );
+use List::MoreUtils qw(first_index);
 #use Data::Dumper; $Data::Dumper::Sortkeys = 1;
 #=======================================================================
 sub new { bless { points => $_[1] ? $_[1] : 1 }, $_[0]; }
@@ -21,15 +22,22 @@ sub run {
 			push @children, $chromosomes->[$elders[0]];
 			next;
 		}
-		# need some more work on it
-		my $shortest = 0;
+		
+		my ($min, $max) = (0, $#{$chromosomes->[0]} - 1);
 		if($ga->variable_length){
 			for my $el(@elders){
-				$shortest = $el if $#{$chromosomes->[$el]} < $#{$chromosomes->[$shortest]};
+				my $idx = first_index { $_ } @{$chromosomes->[$el]};
+				$min = $idx if $idx > $min;
+				$max = $#{$chromosomes->[$el]} if $#{$chromosomes->[$el]} < $max;
 			}
 		}
-	
-		my @points = map { 1+ int(rand $#{$chromosomes->[$shortest]}) } 1..$self->{points};
+		
+		my @points;
+		if($min < $max and $max - $min > 2){
+			my $range = $max - $min;
+			@points = map { $min + int(rand $range) } 1..$self->{points};
+		}
+		
 		@elders = map { clone($chromosomes->[$_]) } @elders;
 		for my $pt(@points){
 			@elders = sort {
